From 7d8f656d10e1d479ca7f71d9d4a9c000153828a7 Mon Sep 17 00:00:00 2001
From: Johannes Schumann <jschumann@km3net.de>
Date: Wed, 22 Jan 2020 22:43:33 +0100
Subject: [PATCH] Apply suggestion to km3io/daq.py

---
 km3io/daq.py | 8 +++++++-
 1 file changed, 7 insertions(+), 1 deletion(-)

diff --git a/km3io/daq.py b/km3io/daq.py
index 9ca2d7f..dd314f0 100644
--- a/km3io/daq.py
+++ b/km3io/daq.py
@@ -45,7 +45,13 @@ def unpack_bits(value):
 
 
 def get_channel_flags(value):
-    """Returns the hrv/fifo flags for the PMT channels (hrv/fifo)"""
+    """Returns the hrv/fifo flags for the PMT channels (hrv/fifo)
+
+    Parameters
+    ----------
+    value : int32
+        The integer value to be parsed.
+    """
     channel_bits = np.bitwise_and(value, 0x3FFFFFFF)
     flags = unpack_bits(channel_bits)
     return np.flip(flags, axis=1)[:, :31]
-- 
GitLab